@@ -1,6 +1,6 @@
 package Map::Tube::Plugin::Graph;
 
-$Map::Tube::Plugin::Graph::VERSION = '0.06';
+$Map::Tube::Plugin::Graph::VERSION = '0.07';
 
 =head1 NAME
 
@@ -8,7 +8,7 @@ Map::Tube::Plugin::Graph - Graph plugin for Map::Tube.
 
 =head1 VERSION
 
-Version 0.06
+Version 0.07
 
 =cut
 
@@ -165,7 +165,7 @@ sub _label {
     my ($line, $tube) = @_;
 
     $tube = '' unless defined $tube;
-    return sprintf("%s Map: %s Line\nGenerated by Map::Tube::Plugin::Graph v%s\nTimestamp: %s",
+    return sprintf("%s Map: %s Line (Generated by Map::Tube::Plugin::Graph v%s at %s)",
                    $tube, $line, $Map::Tube::Plugin::Graph::VERSION, _timestamp());
 }
 
